Index: /trunk/MagicSoft/Simulation/Detector/Camera/creadparam.h
===================================================================
--- /trunk/MagicSoft/Simulation/Detector/Camera/creadparam.h	(revision 1231)
+++ /trunk/MagicSoft/Simulation/Detector/Camera/creadparam.h	(revision 1232)
@@ -19,7 +19,7 @@
 //=
 //= $RCSfile: creadparam.h,v $
-//= $Revision: 1.12 $
+//= $Revision: 1.13 $
 //= $Author: blanch $ 
-//= $Date: 2002-02-28 15:08:01 $
+//= $Date: 2002-03-04 17:20:50 $
 //=
 //=//////////////////////////////////////////////////////////////////////
@@ -169,10 +169,11 @@
 T(data_from_stdin), /* to read data from STDIN */ \
 T(skip),            /* skip pathological showers */ \
-T(read_phe_all),    /* id., but was processed with write_all_images */ \
+T(read_phe_all),    /* id., but was processed with write_all_events */ \
 T(read_phe),        /* read an already camera processed file */ \
-T(write_all_images),/* write to file .phe ALL images (even w.o. trigger)*/ \
+T(write_all_events),/* write to file .phe ALL images (even w.o. trigger)*/ \
 T(nowrite_McEvt),   /* nowrite to file .root McEvt infos */ \
 T(write_McTrig),    /* write to file .root McTrig infos */ \
 T(write_McFadc),    /* write to file .root McFadc infos */ \
+T(nowrite_RawEvt),   /* write to file .root RawData infos */ \
 T(write_all_data),  /* write to file .dat ALL image data */ \
 T(select_energy),   /* energy range to read: only for .phe files */ \
@@ -246,5 +247,5 @@
 int get_read_phe(void);
 int get_read_phe_all(void);
-int get_write_all_images(void);
+int get_write_all_events(void);
 //
 int get_write_McEvt(void);
@@ -283,4 +284,7 @@
 /*
  * $Log: not supported by cvs2svn $
+ * Revision 1.12  2002/02/28 15:08:01  blanch
+ * Header file for creadparam.cxx 1.14.
+ *
  * Revision 1.11  2002/01/18 17:45:37  blanch
  * Header file for creadparam.cxx 1.13.
